@@ -33,15 +33,7 @@ DaysModel::DaysModel(QObject *parent) :
     m_lastRequestedEventsStartDate(QDate()),
     m_agendaNeedsUpdate(false)
 {
-    QHash<int, QByteArray> roleNames;
 
-    roleNames.insert(isCurrent,              "isCurrent");
-    roleNames.insert(containsEventItems,     "containsEventItems");
-    roleNames.insert(dayNumber,              "dayNumber");
-    roleNames.insert(monthNumber,            "monthNumber");
-    roleNames.insert(yearNumber,             "yearNumber");
-
-    setRoleNames(roleNames);
 }
 
 DaysModel::~DaysModel()
@@ -244,3 +236,14 @@ void DaysModel::setPluginsManager(QObject *manager)
 
     QMetaObject::invokeMethod(this, "update", Qt::QueuedConnection);
 }
+
+QHash<int, QByteArray> DaysModel::roleNames() const
+{
+    return {
+        {isCurrent, "isCurrent"},
+        {containsEventItems, "containsEventItems"},
+        {dayNumber, "dayNumber"},
+        {monthNumber, "monthNumber"},
+        {yearNumber, "yearNumber"}
+    };
+}
