@@ -20,7 +20,6 @@
 #include "containmentactions.h"
 #include "containment.h"
 
-#include "private/packages_p.h"
 #include "private/containmentactions_p.h"
 #include "private/containment_p.h"
 
@@ -134,7 +133,7 @@ QString ContainmentActions::eventToString(QEvent *event)
         QWheelEvent *e = static_cast<QWheelEvent *>(event);
         int o = QObject::staticQtMetaObject.indexOfEnumerator("Orientations");
         QMetaEnum orient = QObject::staticQtMetaObject.enumerator(o);
-        trigger = "wheel:";
+        trigger = QStringLiteral("wheel:");
         trigger += orient.valueToKey(e->orientation());
         modifiers = e->modifiers();
         break;
