@@ -202,15 +202,33 @@ public:
      * Returns a list of all known applets associated with a certain mimetype.
      *
      * @return list of applets
+     *
+     * @deprecated use listAppletMetaDataForMimeType instead
      **/
-    KPluginInfo::List listAppletInfoForMimeType(const QString &mimetype);
+    PLASMA_DEPRECATED KPluginInfo::List listAppletInfoForMimeType(const QString &mimetype);
+
+    /**
+     * Returns a list of all known applets associated with a certain mimetype.
+     *
+     * @return list of applets
+     **/
+    QList<KPluginMetaData> listAppletMetaDataForMimeType(const QString &mimetype);
+
+    /**
+     * Returns a list of all known applets associated with a certain URL.
+     *
+     * @return list of applets
+     *
+     * @deprecated use listAppletMetaDataForUrl instead
+     **/
+    PLASMA_DEPRECATED KPluginInfo::List listAppletInfoForUrl(const QUrl &url);
 
     /**
      * Returns a list of all known applets associated with a certain URL.
      *
      * @return list of applets
      **/
-    KPluginInfo::List listAppletInfoForUrl(const QUrl &url);
+    QList<KPluginMetaData> listAppletMetaDataForUrl(const QUrl &url);
 
     /**
      * Returns a list of all the categories used by installed applets.
